@@ -7,19 +7,25 @@ from typing import Sequence, Union, Iterator
 
 from darts.logging import raise_if_not, get_logger
 from darts import TimeSeries
-from darts.dataprocessing.transformers import BaseDataTransformer, InvertibleDataTransformer, FittableDataTransformer
+from darts.dataprocessing.transformers import (
+    BaseDataTransformer,
+    InvertibleDataTransformer,
+    FittableDataTransformer,
+)
 
 logger = get_logger(__name__)
 
 
 class Pipeline:
-    def __init__(self,
-                 transformers: Sequence[BaseDataTransformer],
-                 copy: bool = False,
-                 verbose: bool = None,
-                 n_jobs: int = None):
+    def __init__(
+        self,
+        transformers: Sequence[BaseDataTransformer],
+        copy: bool = False,
+        verbose: bool = None,
+        n_jobs: int = None,
+    ):
         """
-        Pipeline combines multiple data transformers chaining them together.
+        Pipeline to combine multiple data transformers, chaining them together.
 
         Parameters
         ----------
@@ -28,8 +34,8 @@ class Pipeline:
         copy
             If set makes a (deep) copy of each data transformer before adding them to the pipeline
         n_jobs
-            The number of jobs to run in parallel. Parallel jobs are created only when a `Sequence[TimeSeries]` is
-            passed as input to a method, parallelising operations regarding different `TimeSeries`. Defaults to `1`
+            The number of jobs to run in parallel. Parallel jobs are created only when a ``Sequence[TimeSeries]`` is
+            passed as input to a method, parallelising operations regarding different ``TimeSeries``. Defaults to `1`
             (sequential). Setting the parameter to `-1` means using all the available processors.
             Note: for a small amount of data, the parallelisation overhead could end up increasing the total
             required amount of time.
@@ -39,9 +45,36 @@ class Pipeline:
             Whether to print progress of the operations.
             Note: this parameter will overwrite the value set in each single transformer. Leave this parameter set
             to `None` for keeping the transformers configurations.
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from darts import TimeSeries
+        >>> from darts.datasets import AirPassengersDataset
+        >>> from darts.dataprocessing.transformers import Scaler, MissingValuesFiller
+        >>> from darts.dataprocessing.pipeline import Pipeline
+        >>> values = np.arange(start=0, stop=12.5, step=2.5)
+        >>> values[1:3] = np.nan
+        >>> series = series.from_values(values)
+        >>> pipeline = Pipeline([MissingValuesFiller(), Scaler()])
+        >>> series_transformed = pipeline.fit_transform(series)
+        <TimeSeries (DataArray) (time: 5, component: 1, sample: 1)>
+        array([[[0.  ]],
+            [[0.25]],
+            [[0.5 ]],
+            [[0.75]],
+            [[1.  ]]])
+        Coordinates:
+        * time       (time) int64 0 1 2 3 4
+        * component  (component) object '0'
+        Dimensions without coordinates: sample
         """
-        raise_if_not(all((isinstance(t, BaseDataTransformer)) for t in transformers),
-                     "transformers should be objects deriving from BaseDataTransformer", logger)
+
+        raise_if_not(
+            all((isinstance(t, BaseDataTransformer)) for t in transformers),
+            "transformers should be objects deriving from BaseDataTransformer",
+            logger,
+        )
 
         if transformers is None or len(transformers) == 0:
             logger.warning("Empty pipeline created")
@@ -51,7 +84,9 @@ class Pipeline:
         else:
             self._transformers = transformers
 
-        self._invertible = all((isinstance(t, InvertibleDataTransformer) for t in self._transformers))
+        self._invertible = all(
+            (isinstance(t, InvertibleDataTransformer) for t in self._transformers)
+        )
 
         if verbose is not None:
             for transformer in self._transformers:
@@ -79,13 +114,17 @@ class Pipeline:
                 last_fittable_idx = idx
 
         for idx, transformer in enumerate(self._transformers):
-            if idx <= last_fittable_idx and isinstance(transformer, FittableDataTransformer):
+            if idx <= last_fittable_idx and isinstance(
+                transformer, FittableDataTransformer
+            ):
                 transformer.fit(data)
 
             if idx < last_fittable_idx:
                 data = transformer.transform(data)
 
-    def fit_transform(self, data: Union[TimeSeries, Sequence[TimeSeries]]) -> Union[TimeSeries, Sequence[TimeSeries]]:
+    def fit_transform(
+        self, data: Union[TimeSeries, Sequence[TimeSeries]]
+    ) -> Union[TimeSeries, Sequence[TimeSeries]]:
         """
         For each data transformer in the pipeline, first fit the data if transformer is fittable then transform data
         using fitted transformer. The transformed data is then passed to next transformer.
@@ -107,7 +146,9 @@ class Pipeline:
             data = transformer.transform(data)
         return data
 
-    def transform(self, data: Union[TimeSeries, Sequence[TimeSeries]]) -> Union[TimeSeries, Sequence[TimeSeries]]:
+    def transform(
+        self, data: Union[TimeSeries, Sequence[TimeSeries]]
+    ) -> Union[TimeSeries, Sequence[TimeSeries]]:
         """
         For each data transformer in pipeline transform data. Then transformed data is passed to next transformer.
 
@@ -125,9 +166,9 @@ class Pipeline:
             data = transformer.transform(data)
         return data
 
-    def inverse_transform(self,
-                          data: Union[TimeSeries, Sequence[TimeSeries]],
-                          partial: bool = False) -> Union[TimeSeries, Sequence[TimeSeries]]:
+    def inverse_transform(
+        self, data: Union[TimeSeries, Sequence[TimeSeries]], partial: bool = False
+    ) -> Union[TimeSeries, Sequence[TimeSeries]]:
         """
         For each data transformer in the pipeline, inverse-transform data. Then inverse transformed data is passed to
         the next transformer. Transformers are traversed in reverse order. Raises value error if not all of the
@@ -148,7 +189,11 @@ class Pipeline:
             Inverse transformed data.
         """
         if not partial:
-            raise_if_not(self._invertible, "Not all transformers in the pipeline can perform inverse_transform", logger)
+            raise_if_not(
+                self._invertible,
+                "Not all transformers in the pipeline can perform inverse_transform",
+                logger,
+            )
 
             for transformer in reversed(self._transformers):
                 data = transformer.inverse_transform(data)
@@ -171,7 +216,7 @@ class Pipeline:
         """
         return self._invertible
 
-    def __getitem__(self, key: Union[int, slice]) -> 'Pipeline':
+    def __getitem__(self, key: Union[int, slice]) -> "Pipeline":
         """
         Gets subset of Pipeline based either on index or slice with indexes.
         Resulting pipeline will deep copy transformers of the original pipeline.
@@ -186,7 +231,11 @@ class Pipeline:
         Pipeline
             Subset of pipeline determined by key.
         """
-        raise_if_not(isinstance(key, int) or isinstance(key, slice), "key must be either an int or a slice", logger)
+        raise_if_not(
+            isinstance(key, int) or isinstance(key, slice),
+            "key must be either an int or a slice",
+            logger,
+        )
 
         if isinstance(key, int):
             transformers = [self._transformers[key]]
