@@ -8,22 +8,23 @@ returns a `TimeSeries` that is a filtered version of `series`.
 from abc import ABC, abstractmethod
 
 from darts.timeseries import TimeSeries
-from darts.logging import get_logger
+from darts.logging import get_logger, raise_if_not
 
 logger = get_logger(__name__)
 
 
 class FilteringModel(ABC):
-    """ The base class for filtering models. It defines the *minimal* behavior that all filtering models
-        have to support. The filtering models are all "local" models; meaning they act on one time series alone.
+    """The base class for filtering models. It defines the *minimal* behavior that all filtering models
+    have to support. The filtering models are all "local" models; meaning they act on one time series alone.
     """
+
     @abstractmethod
     def __init__(self):
         pass
 
     @abstractmethod
-    def filter(self,  series: TimeSeries) -> TimeSeries:
-        """ Filters a given series
+    def filter(self, series: TimeSeries) -> TimeSeries:
+        """Filters a given series
 
         Parameters
         ----------
@@ -35,4 +36,7 @@ class FilteringModel(ABC):
         TimeSeries
             A time series containing the filtered values.
         """
-        pass
+        raise_if_not(
+            series.is_deterministic,
+            "The input series must be deterministic (observations).",
+        )
