@@ -13,7 +13,10 @@ import torch.nn as nn
 from darts.logging import get_logger, raise_log, raise_if_not
 from darts.utils.torch import random_method
 from darts.utils.likelihood_models import Likelihood
-from darts.models.forecasting.torch_forecasting_model import TorchParametricProbabilisticForecastingModel, PastCovariatesTorchModel
+from darts.models.forecasting.torch_forecasting_model import (
+    TorchParametricProbabilisticForecastingModel,
+    PastCovariatesTorchModel,
+)
 
 logger = get_logger(__name__)
 
@@ -24,38 +27,45 @@ class _GType(Enum):
     SEASONALITY = 3
 
 
-GTypes = NewType('GTypes', _GType)
+GTypes = NewType("GTypes", _GType)
 
 
 class _TrendGenerator(nn.Module):
-
-    def __init__(self,
-                 expansion_coefficient_dim,
-                 target_length):
+    def __init__(self, expansion_coefficient_dim, target_length):
         super(_TrendGenerator, self).__init__()
 
         # basis is of size (expansion_coefficient_dim, target_length)
-        basis = torch.stack([(torch.arange(target_length) / target_length)**i for i in range(expansion_coefficient_dim)], 
-                            dim=1).T
+        basis = torch.stack(
+            [
+                (torch.arange(target_length) / target_length) ** i
+                for i in range(expansion_coefficient_dim)
+            ],
+            dim=1,
+        ).T
 
         self.basis = nn.Parameter(basis, requires_grad=False)
 
-
     def forward(self, x):
         return torch.matmul(x, self.basis)
 
 
 class _SeasonalityGenerator(nn.Module):
-
-    def __init__(self,
-                 target_length):
+    def __init__(self, target_length):
         super(_SeasonalityGenerator, self).__init__()
         half_minus_one = int(target_length / 2 - 1)
-        cos_vectors = [torch.cos(torch.arange(target_length) * 2 * np.pi * i) for i in range(1, half_minus_one + 1)]
-        sin_vectors = [torch.sin(torch.arange(target_length) * 2 * np.pi * i) for i in range(1, half_minus_one + 1)]
-        
+        cos_vectors = [
+            torch.cos(torch.arange(target_length) * 2 * np.pi * i)
+            for i in range(1, half_minus_one + 1)
+        ]
+        sin_vectors = [
+            torch.sin(torch.arange(target_length) * 2 * np.pi * i)
+            for i in range(1, half_minus_one + 1)
+        ]
+
         # basis is of size (2 * int(target_length / 2 - 1) + 1, target_length)
-        basis = torch.stack([torch.ones(target_length)] + cos_vectors + sin_vectors, dim=1).T
+        basis = torch.stack(
+            [torch.ones(target_length)] + cos_vectors + sin_vectors, dim=1
+        ).T
 
         self.basis = nn.Parameter(basis, requires_grad=False)
 
@@ -64,16 +74,17 @@ class _SeasonalityGenerator(nn.Module):
 
 
 class _Block(nn.Module):
-
-    def __init__(self,
-                 num_layers: int,
-                 layer_width: int,
-                 nr_params: int,
-                 expansion_coefficient_dim: int,
-                 input_chunk_length: int,
-                 target_length: int,
-                 g_type: GTypes):
-        """ PyTorch module implementing the basic building block of the N-BEATS architecture.
+    def __init__(
+        self,
+        num_layers: int,
+        layer_width: int,
+        nr_params: int,
+        expansion_coefficient_dim: int,
+        input_chunk_length: int,
+        target_length: int,
+        g_type: GTypes,
+    ):
+        """PyTorch module implementing the basic building block of the N-BEATS architecture.
 
         The blocks produce outputs of size (target_length, nr_params); i.e.
         "one vector per parameter". The parameters are predicted only for forecast outputs.
@@ -122,24 +133,36 @@ class _Block(nn.Module):
 
         # fully connected stack before fork
         self.linear_layer_stack_list = [nn.Linear(input_chunk_length, layer_width)]
-        self.linear_layer_stack_list += [nn.Linear(layer_width, layer_width) for _ in range(num_layers - 1)]
+        self.linear_layer_stack_list += [
+            nn.Linear(layer_width, layer_width) for _ in range(num_layers - 1)
+        ]
         self.fc_stack = nn.ModuleList(self.linear_layer_stack_list)
 
         # Fully connected layer producing forecast/backcast expansion coeffcients (waveform generator parameters).
         # The coefficients are emitted for each parameter of the likelihood.
         if g_type == _GType.SEASONALITY:
-            self.backcast_linear_layer = nn.Linear(layer_width, 2 * int(input_chunk_length / 2 - 1) + 1)
-            self.forecast_linear_layer = nn.Linear(layer_width, nr_params * (2 * int(target_length / 2 - 1) + 1))
+            self.backcast_linear_layer = nn.Linear(
+                layer_width, 2 * int(input_chunk_length / 2 - 1) + 1
+            )
+            self.forecast_linear_layer = nn.Linear(
+                layer_width, nr_params * (2 * int(target_length / 2 - 1) + 1)
+            )
         else:
-            self.backcast_linear_layer = nn.Linear(layer_width, expansion_coefficient_dim)
-            self.forecast_linear_layer = nn.Linear(layer_width, nr_params * expansion_coefficient_dim)
+            self.backcast_linear_layer = nn.Linear(
+                layer_width, expansion_coefficient_dim
+            )
+            self.forecast_linear_layer = nn.Linear(
+                layer_width, nr_params * expansion_coefficient_dim
+            )
 
         # waveform generator functions
         if g_type == _GType.GENERIC:
             self.backcast_g = nn.Linear(expansion_coefficient_dim, input_chunk_length)
             self.forecast_g = nn.Linear(expansion_coefficient_dim, target_length)
         elif g_type == _GType.TREND:
-            self.backcast_g = _TrendGenerator(expansion_coefficient_dim, input_chunk_length)
+            self.backcast_g = _TrendGenerator(
+                expansion_coefficient_dim, input_chunk_length
+            )
             self.forecast_g = _TrendGenerator(expansion_coefficient_dim, target_length)
         elif g_type == _GType.SEASONALITY:
             self.backcast_g = _SeasonalityGenerator(input_chunk_length)
@@ -172,18 +195,18 @@ class _Block(nn.Module):
 
 
 class _Stack(nn.Module):
-
-    def __init__(self,
-                 num_blocks: int,
-                 num_layers: int,
-                 layer_width: int,
-                 nr_params: int,
-                 expansion_coefficient_dim: int,
-                 input_chunk_length: int,
-                 target_length: int,
-                 g_type: GTypes,
-                 ):
-        """ PyTorch module implementing one stack of the N-BEATS architecture that comprises multiple basic blocks.
+    def __init__(
+        self,
+        num_blocks: int,
+        num_layers: int,
+        layer_width: int,
+        nr_params: int,
+        expansion_coefficient_dim: int,
+        input_chunk_length: int,
+        target_length: int,
+        g_type: GTypes,
+    ):
+        """PyTorch module implementing one stack of the N-BEATS architecture that comprises multiple basic blocks.
 
         Parameters
         ----------
@@ -226,27 +249,41 @@ class _Stack(nn.Module):
 
         if g_type == _GType.GENERIC:
             self.blocks_list = [
-                _Block(num_layers, layer_width, nr_params, 
-                       expansion_coefficient_dim, input_chunk_length, 
-                       target_length, g_type)
+                _Block(
+                    num_layers,
+                    layer_width,
+                    nr_params,
+                    expansion_coefficient_dim,
+                    input_chunk_length,
+                    target_length,
+                    g_type,
+                )
                 for _ in range(num_blocks)
             ]
         else:
             # same block instance is used for weight sharing
-            interpretable_block = _Block(num_layers, layer_width, nr_params,
-                                         expansion_coefficient_dim, input_chunk_length, 
-                                         target_length, g_type)
+            interpretable_block = _Block(
+                num_layers,
+                layer_width,
+                nr_params,
+                expansion_coefficient_dim,
+                input_chunk_length,
+                target_length,
+                g_type,
+            )
             self.blocks_list = [interpretable_block] * num_blocks
 
         self.blocks = nn.ModuleList(self.blocks_list)
 
     def forward(self, x):
         # One forecast vector per parameter in the distribution
-        stack_forecast = torch.zeros(x.shape[0], 
-                                     self.target_length, 
-                                     self.nr_params, 
-                                     device=x.device, 
-                                     dtype=x.dtype)
+        stack_forecast = torch.zeros(
+            x.shape[0],
+            self.target_length,
+            self.nr_params,
+            device=x.device,
+            dtype=x.dtype,
+        )
 
         for block in self.blocks_list:
             # pass input through block
@@ -264,22 +301,22 @@ class _Stack(nn.Module):
 
 
 class _NBEATSModule(nn.Module):
-
-    def __init__(self,
-                 input_dim: int,
-                 output_dim: int,
-                 nr_params: int,
-                 input_chunk_length: int,
-                 output_chunk_length: int,
-                 generic_architecture: bool,
-                 num_stacks: int,
-                 num_blocks: int,
-                 num_layers: int,
-                 layer_widths: List[int],
-                 expansion_coefficient_dim: int,
-                 trend_polynomial_degree: int
-                 ):
-        """ PyTorch module implementing the N-BEATS architecture.
+    def __init__(
+        self,
+        input_dim: int,
+        output_dim: int,
+        nr_params: int,
+        input_chunk_length: int,
+        output_chunk_length: int,
+        generic_architecture: bool,
+        num_stacks: int,
+        num_blocks: int,
+        num_layers: int,
+        layer_widths: List[int],
+        expansion_coefficient_dim: int,
+        trend_polynomial_degree: int,
+    ):
+        """PyTorch module implementing the N-BEATS architecture.
 
         Parameters
         ----------
@@ -336,34 +373,40 @@ class _NBEATSModule(nn.Module):
 
         if generic_architecture:
             self.stacks_list = [
-                _Stack(num_blocks,
-                       num_layers,
-                       layer_widths[i],
-                       nr_params,
-                       expansion_coefficient_dim,
-                       self.input_chunk_length_multi,
-                       self.target_length,
-                       _GType.GENERIC)
+                _Stack(
+                    num_blocks,
+                    num_layers,
+                    layer_widths[i],
+                    nr_params,
+                    expansion_coefficient_dim,
+                    self.input_chunk_length_multi,
+                    self.target_length,
+                    _GType.GENERIC,
+                )
                 for i in range(num_stacks)
             ]
         else:
             num_stacks = 2
-            trend_stack = _Stack(num_blocks,
-                                 num_layers,
-                                 layer_widths[0],
-                                 nr_params,
-                                 trend_polynomial_degree + 1,
-                                 self.input_chunk_length_multi,
-                                 self.target_length,
-                                 _GType.TREND)
-            seasonality_stack = _Stack(num_blocks,
-                                       num_layers,
-                                       layer_widths[1],
-                                       nr_params,
-                                       -1,
-                                       self.input_chunk_length_multi,
-                                       self.target_length,
-                                       _GType.SEASONALITY)
+            trend_stack = _Stack(
+                num_blocks,
+                num_layers,
+                layer_widths[0],
+                nr_params,
+                trend_polynomial_degree + 1,
+                self.input_chunk_length_multi,
+                self.target_length,
+                _GType.TREND,
+            )
+            seasonality_stack = _Stack(
+                num_blocks,
+                num_layers,
+                layer_widths[1],
+                nr_params,
+                -1,
+                self.input_chunk_length_multi,
+                self.target_length,
+                _GType.SEASONALITY,
+            )
             self.stacks_list = [trend_stack, seasonality_stack]
 
         self.stacks = nn.ModuleList(self.stacks_list)
@@ -383,11 +426,13 @@ class _NBEATSModule(nn.Module):
         x = x.squeeze(dim=2)
 
         # One vector of length target_length per parameter in the distribution
-        y = torch.zeros(x.shape[0], 
-                        self.target_length,
-                        self.nr_params,
-                        device=x.device, 
-                        dtype=x.dtype)
+        y = torch.zeros(
+            x.shape[0],
+            self.target_length,
+            self.nr_params,
+            device=x.device,
+            dtype=x.dtype,
+        )
 
         for stack in self.stacks_list:
             # compute stack output
@@ -399,38 +444,44 @@ class _NBEATSModule(nn.Module):
             # set current stack residual as input for next stack
             x = stack_residual
 
-        # In multivariate case, we get a result [x1_param1, x1_param2], [y1_param1, y1_param2], [x2..], [y2..], ... 
+        # In multivariate case, we get a result [x1_param1, x1_param2], [y1_param1, y1_param2], [x2..], [y2..], ...
         # We want to reshape to original format. We also get rid of the covariates and keep only the target dimensions.
         # The covariates are by construction added as extra time series on the right side. So we need to get rid of this
         # right output (keeping only :self.output_dim).
-        y = y.view(y.shape[0], self.output_chunk_length, self.input_dim, self.nr_params)[:, :, :self.output_dim, :]
+        y = y.view(
+            y.shape[0], self.output_chunk_length, self.input_dim, self.nr_params
+        )[:, :, : self.output_dim, :]
 
         return y
 
 
-class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTorchModel):
+class NBEATSModel(
+    TorchParametricProbabilisticForecastingModel, PastCovariatesTorchModel
+):
     @random_method
-    def __init__(self,
-                 input_chunk_length: int,
-                 output_chunk_length: int,
-                 generic_architecture: bool = True,
-                 num_stacks: int = 30,
-                 num_blocks: int = 1,
-                 num_layers: int = 4,
-                 layer_widths: Union[int, List[int]] = 256,
-                 expansion_coefficient_dim: int = 5,
-                 trend_polynomial_degree: int = 2,
-                 likelihood: Optional[Likelihood] = None,
-                 random_state: Optional[Union[int, RandomState]] = None,
-                 **kwargs):
-        """ Neural Basis Expansion Analysis Time Series Forecasting (N-BEATS).
+    def __init__(
+        self,
+        input_chunk_length: int,
+        output_chunk_length: int,
+        generic_architecture: bool = True,
+        num_stacks: int = 30,
+        num_blocks: int = 1,
+        num_layers: int = 4,
+        layer_widths: Union[int, List[int]] = 256,
+        expansion_coefficient_dim: int = 5,
+        trend_polynomial_degree: int = 2,
+        likelihood: Optional[Likelihood] = None,
+        random_state: Optional[Union[int, RandomState]] = None,
+        **kwargs
+    ):
+        """Neural Basis Expansion Analysis Time Series Forecasting (N-BEATS).
 
-        This is an implementation of the N-BEATS architecture, as outlined in this paper:
-        https://openreview.net/forum?id=r1ecqn4YwB
+        This is an implementation of the N-BEATS architecture, as outlined in [1]_.
 
         In addition to the univariate version presented in the paper, our implementation also
         supports multivariate series (and covariates) by flattening the model inputs to a 1-D series
-        and reshaping the outputs to a tensor of appropriate dimensions.
+        and reshaping the outputs to a tensor of appropriate dimensions. Furthermore, it also
+        supports producing probabilistic forecasts (by specifying a `likelihood` parameter).
 
         This model supports past covariates (known for `input_chunk_length` points before prediction time).
 
@@ -468,7 +519,7 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
             If no likelihood model is provided, forecasts will be deterministic.
         random_state
             Control the randomness of the weights initialization. Check this
-            `link <https://scikit-learn.org/stable/glossary.html#term-random-state>`_ for more details.
+            `link <https://scikit-learn.org/stable/glossary.html#term-random_state>`_ for more details.
 
         batch_size
             Number of time series (input and output sequences) used in each training pass.
@@ -477,7 +528,7 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
         add_encoders
             A large number of past and future covariates can be automatically generated with `add_encoders`.
             This can be done by adding mutliple pre-defined index encoders and/or custom user-made functions that
-            will be used as index encoders. Additionally, a transformer such as Darts' Scaler() can be added to
+            will be used as index encoders. Additionally, a transformer such as Darts' :class:`Scaler` can be added to
             transform the generated covariates. This happens all under one hood and only needs to be specified at
             model creation.
             Read :meth:`SequentialEncoder <darts.utils.data.encoders.SequentialEncoder>` to find out more about
@@ -488,16 +539,16 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
 
                 add_encoders={
                     'cyclic': {'future': ['month']},
-                    'datetime_attribute': {'past': ['hour'], 'future': ['year', 'dayofweek']},
+                    'datetime_attribute': {'future': ['hour', 'dayofweek']},
                     'position': {'past': ['absolute'], 'future': ['relative']},
-                    'custom': {'past': [lambda index: (index.year - 1950) / 50]},
+                    'custom': {'past': [lambda idx: (idx.year - 1950) / 50]},
                     'transformer': Scaler()
                 }
             ..
         optimizer_cls
             The PyTorch optimizer class to be used (default: `torch.optim.Adam`).
         optimizer_kwargs
-            Optionally, some keyword arguments for the PyTorch optimizer (e.g., `{'lr': 1e-3}`
+            Optionally, some keyword arguments for the PyTorch optimizer (e.g., ``{'lr': 1e-3}``
             for specifying a learning rate). Otherwise the default values of the selected `optimizer_cls`
             will be used.
         lr_scheduler_cls
@@ -508,13 +559,13 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
         loss_fn
             PyTorch loss function used for training.
             This parameter will be ignored for probabilistic models if the `likelihood` parameter is specified.
-            Default: `torch.nn.MSELoss()`.
+            Default: ``torch.nn.MSELoss()``.
         model_name
             Name of the model. Used for creating checkpoints and saving tensorboard data. If not specified,
-            defaults to the following string "YYYY-mm-dd_HH:MM:SS_torch_model_run_PID", where the initial part of the
+            defaults to the following string ``"YYYY-mm-dd_HH:MM:SS_torch_model_run_PID"``, where the initial part of the
             name is formatted with the local date and time, while PID is the processed ID (preventing models spawned at
             the same time by different processes to share the same model_name). E.g.,
-            2021-06-14_09:53:32_torch_model_run_44607.
+            ``"2021-06-14_09:53:32_torch_model_run_44607"``.
         work_dir
             Path of the working directory, where to save checkpoints and Tensorboard summaries.
             (default: current working directory).
@@ -523,7 +574,7 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
             `[work_dir]/.darts/runs/`.
         nr_epochs_val_period
             Number of epochs to wait before evaluating the validation loss (if a validation
-            `TimeSeries` is passed to the `fit()` method).
+            ``TimeSeries`` is passed to the :func:`fit()` method).
         torch_device_str
             Optionally, a string indicating the torch device to use. (default: "cuda:0" if a GPU
             is available, otherwise "cpu")
@@ -532,18 +583,24 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
             be discarded).
         save_checkpoints
             Whether or not to automatically save the untrained model and checkpoints from training.
-            If set to `False`, the model can still be manually saved using :meth:`save_model()
-            <TorchForeCastingModel.save_model()>` and loaded using :meth:`load_model()
-            <TorchForeCastingModel.load_model()>`.
+            If set to `False`, the model can still be manually saved using :func:`save_model()`
+            and loaded using :func:`load_model()`.
+
+        References
+        ----------
+        .. [1] https://openreview.net/forum?id=r1ecqn4YwB
         """
 
-        kwargs['input_chunk_length'] = input_chunk_length
-        kwargs['output_chunk_length'] = output_chunk_length
+        kwargs["input_chunk_length"] = input_chunk_length
+        kwargs["output_chunk_length"] = output_chunk_length
         super().__init__(likelihood=likelihood, **kwargs)
 
-        raise_if_not(isinstance(layer_widths, int) or len(layer_widths) == num_stacks,
-                     "Please pass an integer or a list of integers with length `num_stacks`"
-                     "as value for the `layer_widths` argument.", logger)
+        raise_if_not(
+            isinstance(layer_widths, int) or len(layer_widths) == num_stacks,
+            "Please pass an integer or a list of integers with length `num_stacks`"
+            "as value for the `layer_widths` argument.",
+            logger,
+        )
 
         self.input_chunk_length = input_chunk_length
         self.output_chunk_length = output_chunk_length
@@ -563,7 +620,9 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
 
     def _create_model(self, train_sample: Tuple[torch.Tensor]) -> torch.nn.Module:
         # samples are made of (past_target, past_covariates, future_target)
-        input_dim = train_sample[0].shape[1] + (train_sample[1].shape[1] if train_sample[1] is not None else 0)
+        input_dim = train_sample[0].shape[1] + (
+            train_sample[1].shape[1] if train_sample[1] is not None else 0
+        )
         output_dim = train_sample[-1].shape[1]
         nr_params = 1 if self.likelihood is None else self.likelihood.num_parameters
 
@@ -579,9 +638,9 @@ class NBEATSModel(TorchParametricProbabilisticForecastingModel, PastCovariatesTo
             num_layers=self.num_layers,
             layer_widths=self.layer_widths,
             expansion_coefficient_dim=self.expansion_coefficient_dim,
-            trend_polynomial_degree=self.trend_polynomial_degree
+            trend_polynomial_degree=self.trend_polynomial_degree,
         )
-    
+
     @random_method
     def _produce_predict_output(self, x):
         if self.likelihood:
