@@ -24,7 +24,7 @@ logger = get_logger(__name__)
 
 class VARIMA(DualCovariatesForecastingModel):
     def __init__(self, p: int = 1, d: int = 0, q: int = 0, trend: Optional[str] = None):
-        """ VARIMA
+        """VARIMA
 
         Parameters
         ----------
@@ -39,9 +39,9 @@ class VARIMA(DualCovariatesForecastingModel):
         q : int
             The size of the moving average window (MA).
         trend: str
-            Parameter controlling the deterministic trend. ‘n‘ indicates no trend,
-            ‘c’ a constant term, ‘t’ linear trend in time, and ‘ct’ includes both.
-            Default is ‘c’ for models without integration, and no trend for models with integration.
+            Parameter controlling the deterministic trend. 'n' indicates no trend,
+            'c' a constant term, 't' linear trend in time, and 'ct' includes both.
+            Default is 'c' for models without integration, and no trend for models with integration.
         """
         super().__init__()
         self.p = p
@@ -54,36 +54,50 @@ class VARIMA(DualCovariatesForecastingModel):
 
     def __str__(self):
         if self.d == 0:
-            return 'VARMA({},{})'.format(self.p, self.q)
-        return 'VARIMA({},{},{})'.format(self.p, self.d, self.q)
+            return "VARMA({},{})".format(self.p, self.q)
+        return "VARIMA({},{},{})".format(self.p, self.d, self.q)
 
-    def fit(self, series: TimeSeries, future_covariates: Optional[TimeSeries] = None) -> None:
+    def fit(
+        self, series: TimeSeries, future_covariates: Optional[TimeSeries] = None
+    ) -> None:
         # for VARIMA we need to process target `series` before calling DualForecastingModels' fit() method
-        self._last_values = series.last_values()  # needed for back-transformation when d=1
+        self._last_values = (
+            series.last_values()
+        )  # needed for back-transformation when d=1
         for _ in range(self.d):
-            series = TimeSeries.from_dataframe(series.pd_dataframe(copy=False).diff().dropna())
+            series = TimeSeries.from_dataframe(
+                series.pd_dataframe(copy=False).diff().dropna()
+            )
 
         super().fit(series, future_covariates)
 
-    def _fit(self, series: TimeSeries, future_covariates: Optional[TimeSeries] = None) -> None:
+    def _fit(
+        self, series: TimeSeries, future_covariates: Optional[TimeSeries] = None
+    ) -> None:
         super()._fit(series, future_covariates)
         series = self.training_series
         future_covariates = future_covariates.values() if future_covariates else None
 
-        m = staVARMA(endog=series.pd_dataframe(copy=False),
-                     exog=future_covariates,
-                     order=(self.p, self.q),
-                     trend=self.trend)
+        m = staVARMA(
+            endog=series.pd_dataframe(copy=False),
+            exog=future_covariates,
+            order=(self.p, self.q),
+            trend=self.trend,
+        )
 
         self.model = m.fit(disp=0)
 
-    def _predict(self,
-                 n: int,
-                 future_covariates: Optional[TimeSeries] = None,
-                 num_samples: int = 1) -> TimeSeries:
+    def _predict(
+        self,
+        n: int,
+        future_covariates: Optional[TimeSeries] = None,
+        num_samples: int = 1,
+    ) -> TimeSeries:
 
         super()._predict(n, future_covariates, num_samples)
-        forecast = self.model.forecast(steps=n, exog=future_covariates.values() if future_covariates else None)
+        forecast = self.model.forecast(
+            steps=n, exog=future_covariates.values() if future_covariates else None
+        )
         forecast = self._invert_transformation(forecast)
         return self._build_forecast_series(np.array(forecast))
 
@@ -98,7 +112,9 @@ class VARIMA(DualCovariatesForecastingModel):
         return 30
 
     def _supports_range_index(self) -> bool:
-        raise_if(self.trend and self.trend != "c",
-                 "'trend' is not None. Range indexing is not supported in that case.",
-                 logger)
+        raise_if(
+            self.trend and self.trend != "c",
+            "'trend' is not None. Range indexing is not supported in that case.",
+            logger,
+        )
         return True
