@@ -2,6 +2,7 @@
 Utils for Pytorch and its usage
 -------------------------------
 """
+
 from typing import Callable, TypeVar, Any
 from inspect import signature
 from functools import wraps
@@ -12,7 +13,7 @@ from numpy.random import randint
 
 from darts.logging import raise_if_not, get_logger
 
-T = TypeVar('T')
+T = TypeVar("T")
 logger = get_logger(__name__)
 
 MAX_TORCH_SEED_VALUE = (1 << 31) - 1  # to accommodate 32-bit architectures
@@ -20,7 +21,7 @@ MAX_NUMPY_SEED_VALUE = (1 << 31) - 1
 
 
 def _is_method(func: Callable[..., Any]) -> bool:
-    """ Check if the specified function is a method.
+    """Check if the specified function is a method.
 
     Parameters
     ----------
@@ -34,13 +35,13 @@ def _is_method(func: Callable[..., Any]) -> bool:
     """
     spec = signature(func)
     if len(spec.parameters) > 0:
-        if list(spec.parameters.keys())[0] == 'self':
+        if list(spec.parameters.keys())[0] == "self":
             return True
     return False
 
 
 def random_method(decorated: Callable[..., T]) -> Callable[..., T]:
-    """ Decorator usable on any method within a class that will provide an isolated torch random context.
+    """Decorator usable on any method within a class that will provide an isolated torch random context.
 
     The decorator will store a `_random_instance` property on the object in order to persist successive calls to the RNG
 
@@ -51,16 +52,21 @@ def random_method(decorated: Callable[..., T]) -> Callable[..., T]:
 
     """
     # check that @random_method has been applied to a method.
-    raise_if_not(_is_method(decorated), "@random_method can only be used on methods.", logger)
+    raise_if_not(
+        _is_method(decorated), "@random_method can only be used on methods.", logger
+    )
 
     @wraps(decorated)
     def decorator(self, *args, **kwargs) -> T:
         if "random_state" in kwargs.keys():
             self._random_instance = check_random_state(kwargs["random_state"])
         elif not hasattr(self, "_random_instance"):
-            self._random_instance = check_random_state(randint(0, high=MAX_NUMPY_SEED_VALUE))
+            self._random_instance = check_random_state(
+                randint(0, high=MAX_NUMPY_SEED_VALUE)
+            )
 
         with fork_rng():
             manual_seed(self._random_instance.randint(0, high=MAX_TORCH_SEED_VALUE))
             return decorated(self, *args, **kwargs)
+
     return decorator
